"""Script to store the list of chains with alignments.

This is used in order to read from a single file, the list of the
experimentally resolved PDBs chains, to be used in CM computation.
This contains the alignment file path too, if the chain has missing residues.

This file is used to have a single source from where to read a PDB list and
allow parallelization of the CM computation in batches.
"""
import csv
import pathlib

membrane_dir = pathlib.Path("/mnt/MEMBRANE/")
input_chains_dir = membrane_dir / "CHAINS"
alignments_dir = membrane_dir / "ALIGNMENTS"

chains = {
    ch.name[-10:-4]: [ch] for ch in input_chains_dir.iterdir()
    if ch.suffix == ".pdb"
}
assert len(chains) == 1282

for ali in (
    ali_file for ali_file in alignments_dir.iterdir()
    if ali_file.suffix == ".ali"
):
    chain_name = ali.name[-10:-4]
    chains[chain_name].append(ali)

with open(membrane_dir / "chains_alis.csv", "w", encoding="utf-8") as out_file:
    writer = csv.writer(out_file, delimiter=",")
    writer.writerow(["# Generated by contact_map/list_chains_alignments.py"])
    writer.writerow(["# chain_id", "chain_path", "ali_path"])

    for key, value in chains.items():
        if len(value) == 2:
            writer.writerow([key, str(value[0]), str(value[1])])
        elif len(value) == 1:
            writer.writerow([key, str(value[0])])
        else:
            raise ValueError(f"Chain {key} has {len(value)} paths")
